@@ -13,12 +13,14 @@ __maintainer__ = ["Guido Lemoine", "Konstantinos Anastasakis"]
 __email__ = ""
 __status__ = "Development"
 
-import os
 import sys
-from os.path import join, normcase, exists, normpath
-from cbm.utils import config, update
+
+from os.path import join, normcase, normpath
+from cbm.utils import update
 from pkg_resources import get_distribution, DistributionNotFound
 
+from cbm import show, get, extract, foi, card2db, ipycbm
+
 if sys.version_info < (3, 6):
     print("Not supoted python version, cbm needs python version > 3.6")
     sys.exit()
@@ -36,34 +38,8 @@ except DistributionNotFound:
 else:
     __version__ = _dist.version
 
-paths = config.get_value(['paths'])
-for p in paths:
-    try:
-        if not exists(normpath(join(config.path_work, paths[p]))):
-            os.makedirs(normpath(join(config.path_work, paths[p])))
-            print(f"Directory {p} created successfully")
-    except OSError as err:
-        print(f"Directory {p} can not be created: ", err)
-
-config.create()
 update.check()
 
 
-def chip_images(*args):
-    from cbm.show import chip_images
-    return chip_images.main(*args)
-
-
-def background(*args):
-    from cbm.show import background
-    return background.main(*args)
-
-
-def time_series(*args):
-    from cbm.show import time_series
-    return time_series.main(*args)
-
-
-def calendar(*args):
-    from cbm.show import calendar
-    return calendar.main(*args)
+def init():
+    from cbm.utils import init
